import { Controller, Get, Query, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import {
  ApiBearerAuth,
  ApiOperation,
  ApiQuery,
  ApiTags,
} from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { CarritoMotivoService } from './carrito-motivo.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { GetDto } from './dto/input/get.dto';
import { CarritoMotivoOutputDto } from './dto/output/carrito-motivo.dto';
import { CarritoDto } from '../carrito/dto/input/carrito.dto';

@Controller('carrito-motivo')
@ApiTags('carrito-motivo')
export class CarritoMotivoController {
  constructor(
    private carritoMotivoService: CarritoMotivoService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(CarritoMotivoOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Información de 25 cambios de status de un carrito dependiendo de los filtros enviados.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del carrito.',
    name: 'id_carrito',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el operador.',
    name: 'pagina',
    type: 'string',
  })
  get(@Request() req, @Query() query: GetDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.carritoMotivoService.findAllByIdCarrito(
      operador,
      parseInt(query.id_carrito),
      parseInt(query.pagina),
    );
  }

  @Serealize(CarritoMotivoOutputDto)
  @Get('reporte')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Reporte de todos los cambios de status de un carrito.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del carrito.',
    name: 'id_carrito',
    type: 'string',
  })
  reporte(@Request() req, @Query() query: CarritoDto) {
    const admin: Operador = req.user.operador;

    this.validarUsuarioService.validarAdmin(admin);
    return this.carritoMotivoService.findAllByIdCarrito(
      admin,
      parseInt(query.id_carrito),
    );
  }
}
