import { Controller, Get, Query, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import {
  ApiBearerAuth,
  ApiOperation,
  ApiQuery,
  ApiTags,
} from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { EquipoMotivoService } from './equipo-motivo.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { IdEquipoPaginaDto } from '../dto/input/id-equipo-pagina.dto';
import { ReporteDto } from './dto/input/reporte.dto';
import { EquipoMotivoOutputDto } from './dto/output/equipo-motivo.dto';

@Controller('equipo-motivo')
@ApiTags('equipo-motivo')
export class EquipoMotivoController {
  constructor(
    private equipoMotivoService: EquipoMotivoService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(EquipoMotivoOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Información de 25 cambios de status de un equipo dependiendo de los filtros enviados.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del equipo.',
    name: 'id_equipo',
    type: 'string',
  })
  @ApiQuery({
    description: 'Página en la que se encuentra el operador.',
    name: 'pagina',
    type: 'string',
  })
  get(@Request() req, @Query() query: IdEquipoPaginaDto) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(operador);
    return this.equipoMotivoService.findAllByIdEquipo(
      operador,
      parseInt(query.id_equipo),
      parseInt(query.pagina),
    );
  }

  @Serealize(EquipoMotivoOutputDto)
  @Get('reporte')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Reporte de todos los cambios de status de un equipo.',
  })
  @ApiBearerAuth('jwt')
  @ApiQuery({
    description: 'Id del equipo.',
    name: 'id_equipo',
    type: 'string',
  })
  reporte(@Request() req, @Query() query: ReporteDto) {
    const admin: Operador = req.user.operador;

    this.validarUsuarioService.validarAdmin(admin);
    return this.equipoMotivoService.findAllByIdEquipo(
      admin,
      parseInt(query.id_equipo),
    );
  }
}
