import {
  Body,
  Controller,
  Get,
  Post,
  Request,
  UseGuards,
} from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { TipoUsuarioService } from './tipo-usuario.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { CreateTipoUsuarioDto } from './dto/input/create.dto';
import { MessageOutputDto } from '../dto/output/message.dto';
import { TipoUsuarioOutputDto } from './dto/output/tipo-usuario.dto';

@Controller('tipo-usuario')
@ApiTags('tipo-usuario')
export class TipoUsuarioController {
  constructor(
    private tipoUsuarioService: TipoUsuarioService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Serealize(MessageOutputDto)
  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Crea un nuevo tipo de usuario.' })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Variables que necesita el endpoint.',
    examples: { ejemplo: { value: { tipo_usuario: '' } } },
  })
  create(@Request() req, @Body() body: CreateTipoUsuarioDto) {
    const superAdmin: Operador = req.user.operador;

    this.validarUsuarioService.validarSuperAdmin(superAdmin);
    return this.tipoUsuarioService.create(body.tipo_usuario);
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Todos los tipos de usuario.' })
  @ApiBearerAuth('jwt')
  get(@Request() req) {
    const superAdmin: Operador = req.user.operador;

    this.validarUsuarioService.validarSuperAdmin(superAdmin);
    return this.tipoUsuarioService.findAll();
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get('operador')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Todos los tipos de usuario que puede ver un operador.',
  })
  @ApiBearerAuth('jwt')
  operador(@Request() req) {
    const operador: Operador = req.user.operador;

    this.validarUsuarioService.validarOperador(operador);
    return this.tipoUsuarioService.findAll('operador');
  }
}
